@@ -39,9 +39,9 @@ class Hook(NamespacedResource, MTV):
         self.image = image
         self.playbook = playbook
 
-    def to_dict(self):
+    def to_dict(self) -> None:
         super().to_dict()
-        if not self.yaml_file:
+        if not self.kind_dict and not self.yaml_file:
             self.res.update({
                 "spec": {
                     "image": self.image,
