@@ -35,5 +35,5 @@ class UploadTokenRequest(NamespacedResource):
 
     def to_dict(self) -> None:
         super().to_dict()
-        if not self.yaml_file:
+        if not self.kind_dict and not self.yaml_file:
             self.res.update({"spec": {"pvcName": self.pvc_name}})
